import numpy as np
from scipy.integrate import odeint
import matplotlib.pyplot as plt

# Setter startverdiene for Smittbare, Infiserte, Restituerte og totalpopulasjoNen
S = 1000000
I = 1
R = 0
N = S + I + R

#beta viser hvor smittsom sykdommen er og gamma viser hvor lenge man er syk
beta = 0.02
gamma = 0.01

# t er array for tid som her blir satt til å starte fra dag 0 og gå til dag 3000 med 1000 intervaller
t = np.linspace(0, 3000, 1000)

# Vi lager en vektor med alle startverdiene
SIR_startverdier = S, I, R

# endringer_SIR er funksjonen som viser hvordan S, I og R endrer seg. Vi kan også si at funksjonen gir systemet med differensiallikninger
def endringer_SIR(SIR_verdier, t, N, beta, gamma):
    S, I, R = SIR_verdier
    endring_S = -beta*S*I/N
    endring_I = beta*S*I/N - gamma*I
    endring_R = gamma*I
    return endring_S, endring_I, endring_R

# odeint integrerer systemet vårt med tre differensiallikninger og bruker startverdiene, t, totalpopulasjonen, beta og gamma
SIR_resultat = odeint(endringer_SIR, SIR_startverdier, t, args=(N, beta, gamma))

# Vi henter ut tre arrayer (S_resultat, I_resultat og R_resultat) som inneholder henholdsvis antall smittbare, infiserte og restituerte for alle verdiene i t
S_resultat, I_resultat, R_resultat = SIR_resultat.T

# Plotting av S, I og R mot t
fig, graf = plt.subplots()
graf.plot(t, S_resultat, 'b', alpha=0.5, label='Smittbare')
graf.plot(t, I_resultat, 'r', alpha=0.5, label='Infiserte')
graf.plot(t, R_resultat, 'g', alpha=0.5, label='Restituerte')
graf.ticklabel_format(useOffset=False, style='plain')
graf.set_xlabel('Tid i dager')
graf.set_ylabel('Antall personer')
legend = graf.legend()
plt.show()